#
# spec file for package libyui-ncurses-pkg
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libyui-ncurses-pkg
Version:        2.50.8
Release:        lp152.2.3.1
Source:         %{name}-%{version}.tar.bz2

%define so_version 11
%define bin_name %{name}%{so_version}

%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  libyui-devel >= 3.9.0
BuildRequires:  pkg-config

%define libyui_ncurses_devel_version    libyui-ncurses-devel >= 2.54.0
BuildRequires:  %{libyui_ncurses_devel_version}
%define libzypp_devel_version           libzypp-devel >= 17.21.0
BuildRequires:  %{libzypp_devel_version}

Url:            http://github.com/libyui/
Summary:        Libyui - yast2 package selector widget for the ncurses UI
License:        LGPL-2.1-only OR LGPL-3.0-only
Group:          System/Libraries

%description
This package extends the character based (ncurses) user interface
component for libYUI.


%package -n %{bin_name}

Requires:       libyui%{so_version}
Provides:       %{name} = %{version}

Provides:       yast2-ncurses-pkg = 2.50.0
Obsoletes:      yast2-ncurses-pkg < 2.50.0

# force removal of all previous library versions (bsc#1148622),
# expands to: libyui-ncurses-pkg1 libyui-ncurses-pkg2 ... libyui-ncurses-pkg{so_version - 1}
Obsoletes:      %(echo `seq -s " " -f "libyui-ncurses-pkg%.f" $(expr %{so_version} - 1)`)

Provides:       libyui_pkg
Supplements:    packageand(libyui-ncurses:yast2-packager)

# Selectable::hasRetracted()
Requires:       libzypp >= 17.21.0

Url:            http://github.com/libyui/
Summary:        Libyui - yast2 package selector widget for the ncurses UI
Group:          System/Libraries

%description -n %{bin_name}
This package extends the character based (ncurses) user interface
component for libYUI.



%package devel

Requires:       %{libyui_ncurses_devel_version}
Requires:       %{libzypp_devel_version}
%if 0%{?suse_version} > 1325
Requires:       libboost_headers-devel
%else
Requires:       boost-devel
%endif
Requires:       %{bin_name} = %{version}
Requires:       glibc-devel
Requires:       libstdc++-devel

Url:            http://github.com/libyui/
Summary:        Libyui-ncurses-pkg header files
Group:          Development/Languages/C and C++

%description devel
This package extends the character based (ncurses) user interface
component for libYUI.


This can be used independently of YaST for generic (C++) applications.
This package has very few dependencies.


%prep
%setup -q -n %{name}-%{version}

%build

export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG"

./bootstrap.sh %{_prefix}

mkdir build
cd build

%if %{?_with_debug:1}%{!?_with_debug:0}
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELWITHDEBINFO
%else
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELEASE
%endif

make %{?jobs:-j%jobs}

%install
cd build
make install DESTDIR="$RPM_BUILD_ROOT"
install -m0755 -d $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/
install -m0755 -d $RPM_BUILD_ROOT/%{_libdir}/yui
install -m0644 ../COPYING* $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -n %{bin_name} -p /sbin/ldconfig

%postun -n %{bin_name} -p /sbin/ldconfig

%files -n %{bin_name}
%defattr(-,root,root)
%dir %{_libdir}/yui
%{_libdir}/yui/lib*.so.*
%doc %dir %{_docdir}/%{bin_name}
%license %{_docdir}/%{bin_name}/COPYING*

%files devel
%defattr(-,root,root)
%dir %{_docdir}/%{bin_name}
%{_libdir}/yui/lib*.so
%{_prefix}/include/yui
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}

%changelog
* Mon Oct 18 2021 Stefan Hundhammer <shundhammer@suse.com>
- Fixed crash in NCurses online update when retracted packages
  are present (bsc#1191130)
- 2.50.8
* Tue May 19 2020 Stefan Hundhammer <shundhammer@suse.com>
- Allow vendor change also for distribution upgrade (bsc#1170521)
- 2.50.7
* Mon Feb 17 2020 Stefan Hundhammer <shundhammer@suse.com>
- Removed leftovers of dropping support for RPM group tags (bsc#1163594)
- 2.50.6
* Thu Feb  6 2020 Stefan Hundhammer <shundhammer@suse.com>
- Ask user for confirmation for retracted packages (bsc#1162145)
- 2.50.5
* Thu Jan 23 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add an option to include a "Search Online" option in the
  package selector (jsc#SLE-9109).
- 2.50.4
* Wed Jan 22 2020 Stefan Hundhammer <shundhammer@suse.com>
- Handle retracted packages (jsc#SLE-11211)
- 2.50.3
* Fri Dec 13 2019 aschnell@suse.com
- adapted to changes in libyui-ncurses (needed for bsc#1159177)
- 2.50.2
* Wed Dec 11 2019 Ladislav Slezák <lslezak@suse.cz>
- Added multiversion package list to the package classification
  filter (related to the bsc#1155132)
- 2.50.1
* Tue Dec 10 2019 Rodion Iafarov <riafarov@suse.com>
- Increase SO version to 11 (bsc#1132247)
- 2.50.0
* Thu Sep  5 2019 Ladislav Slezák <lslezak@suse.cz>
- Added a new generic dependency to force upgrade from all previous
  versions (e.g. from libyui-ncurses-pkg9 to libyui-ncurses-pkg10)
  (bsc#1148622)
- 2.49.1
* Thu Apr 11 2019 Ladislav Slezák <lslezak@suse.cz>
- Bump the .so version to 10 to be compatible with the other
  libyui packages (bsc#1132247)
- 2.49.0
* Wed Oct 24 2018 igonzalezsosa@suse.com
- Remove the RPM Groups view (FATE#326485).
- 2.48.9
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Fri Jul 27 2018 lslezak@suse.cz
- Fix for the new FSize class (avoid the 8EiB limit, bsc#991090)
- Update the package version
- 2.48.8
* Tue Jul  3 2018 lslezak@suse.cz
- Fixes for file systems >8EiB (bsc#991090):
  - Do not display "out of disk space" error at start when such
    a large disk is present in the system
  - Fixed displaying negative disk sizes in the disk usage dialog
- 2.48.7
* Fri Jun 29 2018 mvidner@suse.com
- Added new "Services" filter, displayed only when at least one
  repository service is present (FATE#321043)
* Mon Jun 25 2018 aschnell@suse.com
- use long long instead of int for free disk space with MiB base
- 2.48.6
* Mon Aug  7 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- Reduce build dependencies: Use individual libboost-*-devel
  packages instead of boost-devel (amajer)
- 2.48.5
* Tue Dec  6 2016 cwh@suse.com
- Sort pkg list case-insensitively (bsc#1012294)
- Prevent double sorting (widget sorts by itself)
- 2.48.4
* Tue Nov 29 2016 shundhammer@suse.de
- Made menu hotkey unique for QA (bsc#1012604)
- 2.48.3
* Wed Oct  7 2015 jreidinger@suse.com
- Fix unselecting patterns for installation (unify behavior with
  qt packager) (bnc#916568)
- 2.48.2
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Thu Sep 10 2015 schubi@suse.com
- Handle mixed multiversion packages (fate#318778)
- Allow to delete single versions of multiversion packages.
  (bsc#943870)
- 2.48.0
* Wed Jul  8 2015 mvidner@suse.com
- Added option "Dependencies/Install Recommended Packages",
  (PKGMGR_RECOMMENDED) (boo#900853).
- Changed "Dependencies/Install Recommeded Packages for Already
  Installed Packages" from an option to a command (boo#902394).
- 2.47.0
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.46.2
* Mon Jul 28 2014 mvidner@suse.com
- Recommend this package when yast2-packager and libyui-ncurses are
  installed (bnc#888300)
- 2.46.1
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.46.0
* Wed Nov 20 2013 gs@suse.de
- Fixed typos in help text, rephrase text (bnc #839689)
- Version 2.45.0
* Wed Jul 31 2013 gs@suse.de
- Online Update: show multi version packages correctly
- Version 2.44.4
* Wed Jul 24 2013 gs@suse.de
- Online Update: improve help, show column 'Kind' beside 'Name',
  Package Selector: get lists of orphaned, suggested, recommended
  and unneeded packages correctly
- Version 2.44.3
* Thu Jul 11 2013 gs@suse.de
- Online Update: show irrelevant patches only in list 'All Patches',
  improve handling of the patch status, enhance help text
- Version 2.44.2
* Wed Jul  3 2013 gs@suse.de
- remove webpin search from configuration menu (bnc#821866),
  catch exception of sysconfig write (bnc #827608)
- Version 2.44.1
* Thu Jun 27 2013 gs@suse.de
- Show and handle multiple versions of packages correctly
  (bnc #822962)
- Version 2.44.0
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.43.6
* Tue May  7 2013 gs@suse.de
- Cast return of setCandidate() to bool (due to libzypp changes)
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- V 2.43.5
* Thu Feb 21 2013 gs@suse.de
- Show patch descriptions correctly (bnc #803466)
- V 2.43.4
* Tue Jan 22 2013 gs@suse.de
- Bug-fix for package search (concerning package summary)
- V 2.43.3
* Wed Dec 12 2012 gs@suse.de
- Improve help text for recommended packages, fix typos
- V 2.43.2
* Wed Oct 24 2012 gs@suse.de
- Save settings from 'Dependency' menu (bnc # 766598)
- V 2.43.1
* Thu Oct  4 2012 gs@suse.de
- NCPkgTable: bug-fix for sorting the list of packages
- Show function keys in bottom line correctly
- Version 2.43.0
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Tue Jun 19 2012 gs@suse.de
- Fixed crash while starting the package selector (bnc #767619)
* Tue May  8 2012 gs@suse.de
- Bug-fix for typo in help text (bnc #759100)
- add filter for recommended, suggested, orphaned or unneeded
  packages ('Package Classification in 'Filter' list)
- respect locale setting when sorting the list of packages
- 2.22.6
* Tue Apr 17 2012 gs@suse.de
- Merged text from proof-read
- 2.22.5
* Tue Mar 27 2012 gs@suse.de
- Select correct package version and vendor for update (bnc#704123)
- remove libxcrypt-devel from BuildRequires
- 2.22.4
* Wed Mar 14 2012 gs@suse.de
- Online Update: possibility to search in patch summary, improve
  formatting of patch descriptions
- 2.22.3
* Tue Mar  6 2012 gs@suse.de
- Better formatting also for notify messages (bnc #746876)
- 2.22.2
* Thu Mar  1 2012 gs@suse.de
- Better formatting of package and patch descriptions (bnc #691572)
- 2.22.1
* Tue Jan 17 2012 gs@suse.de
- Confirmed license
- 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Oct 25 2011 gs@suse.de
- Set action 'Show Summary' correctly (menu 'Configuration',
  'Action after Package Installation')
- 2.21.2
* Tue Aug  2 2011 lslezak@suse.cz
- added new ignoreAlreadyRecommended solver option to
  the dependencies submenu (bnc#668588)
- 2.21.1
* Tue Apr 26 2011 gs@suse.de
- Adjust NCTree params, require latest libyui
- V 2.21.0
* Wed Feb  9 2011 gs@suse.de
- Require latest libyui
- V 2.20.3
* Wed Feb  2 2011 gs@suse.de
- Internal: code cleanup (esp. NCPackageSelector, NCPkgTable),
  require latest libyui
- V 2.20.2
* Fri Jan  7 2011 tgoettlicher@suse.de
- Fixed incompatibilities caused by checkboxes for treewidgeet
- 2.20.1
* Thu Nov 11 2010 gs@suse.de
- Improve help text for status information and adjust status for
  languages
- 2.20.0
* Thu Aug 19 2010 gs@suse.de
- Show error popup if searching for packages throws an exception
  (bnc #615102)
- 2.19.5
* Tue Jul 27 2010 gs@suse.de
- Show all patterns in 'Filter/Patterns' list
  (bug-fix for bnc#624996)
- 2.19.4
* Wed Jun  9 2010 gs@suse.de
- Use ncursesw6-config to get includes for ncurses6 library
- 2.19.3
* Wed May 26 2010 gs@suse.de
- Use ncurses6 library (adjust INCLUDES in Makefile.am, require
  latest yast2-ncurses - bnc #607767)
- 2.19.2
* Tue May 11 2010 gs@suse.de
- Add options for dependency solver:
  * cleanup when deleting packages
  * allow vendor change
- 2.19.1
* Mon Dec 14 2009 kmachalkova@suse.cz
- Update status of dependent packages when the status of selected
  package changes (redraw corresponding column - bnc#561337)
- 2.19.0
* Thu Nov  5 2009 gs@suse.de
- Start with correct filter view on option `repoMode (repositories)
  and `summaryMode (installation summary) (bnc #548437)
* Wed Jul 22 2009 kmachalkova@suse.cz
- Start webpin client from 'Configuration' menu (FaTE #306928)
* Wed May 27 2009 ma@suse.de
- Remove use of deprecated Package::filenames.
- 2.18.4
* Wed May 27 2009 gs@suse.de
- Sorting the package list by size works correctly (bnc#437217)
- 2.18.3
* Wed May  6 2009 kmachalkova@suse.cz
- Speeding up scrolling big package lists left/right (bnc#498267)
- 2.18.2
* Mon Mar 30 2009 kmachalkova@suse.cz
- Do not implicitly search for matching keywords (added a new switch
  into search options to include/exclude keywords) (bnc#470069)
* Thu Mar 19 2009 gs@suse.de
- Add name of source package to technical details view
* Thu Feb 19 2009 kmachalkova@suse.cz
- New menu for launching repo manager and YOU configuration
- New sub-menu for configuring PKGMGR_ACTION_AT_EXIT sysconfig
  variable
- Focus newly created table/input field after switching between filter
  views
- 2.18.1
* Tue Jan 20 2009 kmachalkova@suse.cz
- Fixed weird behaviour of left/right arrow keys (bnc#467586)
- Speeding up displaying big lists (repository filter & co.) using
  overloaded addItem from parent class - requires new y2-ncurses
  (bnc#467586)
- 2.18.0
* Tue Jan  6 2009 kmachalkova@suse.cz
- Fixed crash after pressing some keys (left, right, backspace)
  handled by parent class of NCPkgTable (bnc#462961)
- Make matching exact string in package search really exact
  (bnc#459719)
* Thu Dec  4 2008 kmachalkova@suse.cz
- Installed patterns/patches are marked as 'i' (bnc#442484)
- Adjusted switching between pattern states (bnc#445415 for ncurses)
- Enables sorting of pkg tables (partially bnc#437217)
- 2.17.11
* Fri Nov  7 2008 kmachalkova@suse.cz
- Sort patterns according to order AND category (bnc#439088)
- 2.17.10
* Thu Nov  6 2008 gs@suse.de
- YOU layout improved (enough space for download size)
- Always update the package table after dependency popup is shown
- Increase width of dependency popup (bnc #441414)
- 2.17.9
* Wed Nov  5 2008 gs@suse.de
- Internal change: delete NCPkgPatchSearch popup correctly
* Thu Oct 23 2008 kmachalkova@suse.cz
- Added explanation of 'satisfied' (:-)) pattern/language
  status (bnc#432528)
- Exclude readonly directories from the checking of available
  diskspace(bnc#384368)
- 2.17.8
* Wed Oct 22 2008 gs@suse.de
- Show a "Searching..." popup during package search
- Warning message added to disk error popup
- Internal changes: disk space testing enabled, comments added
* Wed Oct 15 2008 sh@suse.de
- Require latest libyui-devel (API change!)
- V 2.17.7
* Wed Aug  6 2008 kmachalkova@suse.cz
- Show "Start repository manager" menu only when requested by
  `opt(`repoMgr) flag i.e. not in installation phase (bnc#381956)
- Added filtering packages by status (bnc#384085)
- Internal changes (YOU help, pkg selector modes)
- 2.17.6
* Wed Jul 23 2008 kmachalkova@suse.cz
- Added pkg search modes (contains, regexp etc.) selection (uses
  zypp::PoolQuery)
- Search view is now default (bnc#404694)
- Reset info text area on switching to/from search filter
* Wed Jul 23 2008 ma@suse.de
- Remove references to obsolete freshens dependencies.
- 2.17.5
* Mon Jul 21 2008 kmachalkova@suse.cz
- Some look&feel fixes
  * Show locale (language) description
  * Show repository URL in the description area (not in the table)
  * Show how many packages has been found in this search
- Experimental support for patch searching using zypp::PoolQuery
- 2.17.4
* Thu Jul 17 2008 ma@suse.de
- Remove obsolete references to Script/Message/Atom
* Wed Jun 25 2008 kmachalkova@suse.cz
- Focus the button (instead of text area) and make closing the dialog
  possible with single keypress if applicable (bnc#397393)
- Fixed keyboard shortcut (bnc#402349)
- 2.17.3
* Wed Jun 11 2008 kmachalkova@suse.cz
- Use zypp::PoolQuery to filter packages by repositories
- Use zypp::PoolQuery to search in packages
- Search filter: search directly by hitting Enter on search field
- Update label and the description when switching between repositories
  (bnc#397388)
- 2.17.2
* Tue Jun 10 2008 sh@suse.de
- Now using renamed ::setPreferredSize() calls rather than old
  setNiceSize()
- Fixed broken YaST2 logo headers in some source files
- Removed utterly wrong maintainer: ma@suse.de  lines
- V 2.17.1
* Tue Jun 10 2008 gs@suse.de
- Online Update: add preselected patches to the list of
  needed patches
* Wed Jun  4 2008 gs@suse.de
- Improve dependency popup: show solution details (NCRichText),
  only add NCSpacing if there's enough space
* Thu May 29 2008 gs@suse.de
- Show the status of a language pattern and make installation
  possible (bnc #389722)
- 2.16.13
* Wed May 28 2008 kmachalkova@suse.cz
- Do not create pop-up dialogs on the stack (disk space, deps), this
  may lead to segfault (bnc#384471) and/or the latest pop-up being
  always on the top (bnc#384467)
- 2.16.12
* Wed May 21 2008 gs@suse.de
- YOU: correct condition for unneeded patches
- 2.16.11
* Tue May 20 2008 gs@suse.de
-  update the pattern status after the initial solver run,
  status for "installed" patterns/patches is ':-)',
  correct help text and action menu for YOU
* Wed May  7 2008 gs@suse.de
- internal changes: remove remainings of old style logging,
  rearrange inclusion of header files
- 2.16.10
* Tue May  6 2008 gs@suse.de
- YOU: filter name for satisfied patches is 'Unneeded' (like qt),
    use enum for patch filters,
- Do the initial solver run before showing the default list
* Mon May  5 2008 kmachalkova@suse.cz
- Improved YOU layout, showing YOU help ( by gs )
- The rest of deprecated libzypp stuff removed (by gs)
- PkgMenuExtras: correct ret. value to fix build (by coolo)
- 2.16.9
* Mon Apr 28 2008 kmachalkova@suse.cz
- Locale (prev. Language) support + displaying locale-related pkgs
  re-enabled
- Correctly replace filter description area when switching between
  filters (bnc#377857)
- 2.16.8
* Mon Apr 21 2008 kmachalkova@suse.cz
- Pattern content (required, recommended, suggested pkgs) visible
  again
- Show no. of installed vs. total pkgs for a pattern
- 2.16.7
* Mon Apr 21 2008 jsrain@suse.cz
- fixed textdomain
* Sat Apr 12 2008 coolo@suse.de
- adapt to latest libzypp
* Thu Apr  3 2008 coolo@suse.de
- adapt to latest libzypp
* Tue Apr  1 2008 jsrain@suse.cz
- fixed textdomain
* Mon Mar 31 2008 kmachalkova@suse.cz
- Launch repository manager from the menu (Extras) - return `repo_mgr
  symbol from the main `PackageSelector UI loop (FaTE #302517)
- 2.16.6
* Thu Mar 27 2008 kmachalkova@suse.cz
- UI refactoring branch merged back to trunk
- 2.16.5
* Tue Mar 25 2008 coolo@suse.de
- adapt to libzypp 4.6
- V 2.16.4
* Wed Feb 27 2008 coolo@suse.de
- buildrequire ycp bindings
* Mon Feb 25 2008 sh@suse.de
- Provide yast2_ui_pkg in .spec file (bnc #363958)
- V 2.16.3
* Wed Feb 20 2008 coolo@suse.de
- remove self made logging, use UI
* Fri Feb 15 2008 coolo@suse.de
- compile against libzypp trunk - language support pending
  (#ifed out - want to make sure it works before we spend
  too much time into it)
* Tue Feb 12 2008 kmachalkova@suse.cz
-  Initial version splitted from yast2-ncurses 2.16.15
-  2.16.0
